#!/usr/bin/perl -T

use lib '.'; use lib 't';

require v5.14.0;

use Cwd;
use Config;
use File::Spec;
use File::Temp qw(tempdir);

use Test::More tests => 1;

my $tname = "a2";

my $pathdir = $INC[4];
(-d $pathdir) and File::Spec->file_name_is_absolute($pathdir);

chdir("t");

my $workdir = tempdir("$tname.XXXXXX", DIR => "log");
die "FATAL: failed to create workdir: $!" unless -d $workdir;

ok((-d $workdir), 'tempdir test');
